@@ -285,7 +285,7 @@ class KeytotextTrainer:
             tokenizer=self.tokenizer, model=self.model, output=outputdir
         )
 
-        logger = WandbLogger(name="keytotext", project="keytotext")
+        logger = WandbLogger(project="keytotext")
 
         early_stop_callback = (
             [
@@ -337,7 +337,7 @@ class KeytotextTrainer:
 
     def save_model(
             self,
-            model_dir
+            model_dir="outputs"
     ):
         path = f"{model_dir}/keytotext-epoch-{self.max_epoch}"
         self.tokenizer.save_pretrained(path)
@@ -357,6 +357,7 @@ class KeytotextTrainer:
             early_stopping: bool = True,
             skip_special_tokens: bool = True,
             clean_up_tokenization_spaces: bool = True,
+            use_gpu: bool = True
     ):
         """
         generates prediction for K2T model
@@ -373,9 +374,18 @@ class KeytotextTrainer:
             early_stopping (bool, optional): Defaults to True.
             skip_special_tokens (bool, optional): Defaults to True.
             clean_up_tokenization_spaces (bool, optional): Defaults to True.
+            use_gpu: Defaults to True.
         Returns:
             list[str]: returns predictions
         """
+        if use_gpu:
+            if torch.cuda.is_available():
+                self.device = torch.device("cuda")
+            else:
+                raise Exception("exception ---> no gpu found. set use_gpu=False, to use CPU")
+        else:
+            self.device = torch.device("cpu")
+
         source_text = ' '.join(map(str, keywords))
 
         input_ids = self.tokenizer.encode(
